/*
  Stepper Motor Demonstration 1
  Stepper-Demo1.ino
  Demonstrates 28BYJ-48 Unipolar Stepper with ULN2003 Driver
  Uses Arduino Stepper Library

  DroneBot Workshop 2018
  https://dronebotworkshop.com
*/

// Demo code for Grove - Temperature Sensor V1.1/1.2
// Loovee @ 2015-8-26

//Include the Arduino Stepper Library
#include <Stepper.h>
#include <math.h>  // Library needed for Temperature and HCHO sensors


// Following two constants belonge to th HCHO sensor:

#define Vc 4.95               
#define R0 34.28              //the number of R0 you detected just now

const int B = 4275;               // B value of the thermistor
const int Rinit = 100000;         // Rinit = 100k
const int pinTempSensor = A0;     // temperature sensor connect to A0

// Define Constants

// Number of steps per internal motor revolution 
const float STEPS_PER_REV = 32; 

//  Amount of Gear Reduction
const float GEAR_RED = 64;

// Number of steps per geared output rotation
const float STEPS_PER_OUT_REV = STEPS_PER_REV * GEAR_RED;

// Define Variables

// Number of Steps Required
int StepsRequired;


int LEDred = 3; // Farbe rot an Pin PB2
int LEDgreen = 5; // Colour blue on Pin PB1 (PWM)
int LEDblue = 6; // Farbe gruen an Pin 6
int p = 2000; // p ist eine Pause mit 1000ms also 1 Sekunde
int brightness1a = 200; // Zahlenwert zwischen 0 und 255 â€“ gibt die LeuchtstÃ¤rke der einzelnen Farbe an
int brightness1b = 200; // Zahlenwert zwischen 0 und 255 â€“ gibt die LeuchtstÃ¤rke der einzelnen Farbe an
int brightness1c = 200; //  Zahlenwert zwischen 0 und 255 â€“ gibt die LeuchtstÃ¤rke der einzelnen Farbe an
int dark = 0; // Zahlenwert 0 bedeutet Spannung 0V â€“ also LED aus.


// Create Instance of Stepper Class
// Specify Pins used for motor coils
// The pins used are 8,9,10,11 
// Connected to ULN2003 Motor Driver In1, In2, In3, In4 
// Pins entered in sequence 1-3-2-4 for proper step sequencing


Stepper steppermotor(STEPS_PER_REV, 10, 8, 9, 7);

void setup()
{
// Nothing for stepper  (Stepper Library sets pins as outputs)

    Serial.begin(9600);   //needed for temperature and HCHO sensors data monitoring

    pinMode(LEDblue, OUTPUT);
    pinMode(LEDgreen, OUTPUT);
    pinMode(LEDred, OUTPUT);

}

void loop()
{
//  // Slow - 4-step CW sequence to observe lights on driver board
//  steppermotor.setSpeed(1);    
//  StepsRequired  =  4;
//  steppermotor.step(StepsRequired);
//  delay(2000);


  int a = analogRead(pinTempSensor);

    float R = 1023.0/a-1.0;
    R = Rinit*R;

    float temperature = 1.0/(log(R/Rinit)/B+1/298.15)-273.15 - 2; // convert to temperature via datasheet

    int sensorValue=analogRead(A1);     // read the signal (voltage value) from the pin A1 (analog)
    double Rs=(1023.0/sensorValue)-1;   // calculate Rs out of the read voltage value of pin A1
    
    Serial.print("Rs = ");
    Serial.println(Rs);                 // Print the real value of Rs
    double ppm=pow(10.0,((log10(Rs/R0)-0.0827)/(-0.4807)));  // calculate the HCHO level withs this callculation (ppm)
    
    Serial.print("HCHO ppm = ");        // Print the VOC value 
    Serial.println(ppm);

    
    Serial.print("temperature (degrees Celsius) = ");
    Serial.println(temperature);

    

       // Rotate CW 1/2 turn slowly
      analogWrite(LEDgreen, dark);     
      analogWrite(LEDred, brightness1a);  // red LED on
      StepsRequired  =  STEPS_PER_OUT_REV /4 ; 
      steppermotor.setSpeed(100);   
      steppermotor.step(StepsRequired);
      delay(2*p);                           //The program stops for p seconds
        
      
      
      // Rotate CCW 1/2 turn quickly
      analogWrite(LEDred, dark);            // red LED off
      analogWrite(LEDgreen, brightness1b); // green LED on      
      StepsRequired  =  - STEPS_PER_OUT_REV / 4 ;   
      steppermotor.setSpeed(700);  
      steppermotor.step(StepsRequired);
      delay(p);   
         
    
      // Rotate CW 1/2 turn slowly
      analogWrite(LEDgreen, dark);            // red LED off
      analogWrite(LEDblue, brightness1c); // green LED on    
      StepsRequired  =  STEPS_PER_OUT_REV / 4 ; 
      steppermotor.setSpeed(100);   
      steppermotor.step(StepsRequired);
      delay(2*p);                           //The program stops for p seconds
    
    
       // Rotate CCW 1/2 turn quickly
      
      analogWrite(LEDblue, dark);    // red LED off 
      analogWrite(LEDgreen, brightness1b); // green LED on    
      StepsRequired  =  - STEPS_PER_OUT_REV / 4 ;   
      steppermotor.setSpeed(700);  
      steppermotor.step(StepsRequired);
      delay(p);   

}
